breeds [
  water          ;; water molecules
  hydronium      ;; hydronium ions (green)
  hydroxide      ;; base molecules (red)
  acid           ;; parent acid molecules (yellow)
  conj-base      ;; conjugate base molecules of parent acid (orange)
]

globals [
  pH
  Ka             ;; variable for acid reactions
  base-added     ;; use to keep track of how much base has been added since the last time
                 ;; we plotted a point on the titration curve
]

to setup
  ca
  set-default-shape water "molecule2"
  set-default-shape hydronium "molecule3"
  set-default-shape hydroxide "molecule1"
  set-default-shape acid "molecule2"
  set-default-shape conj-base "molecule1"
  set Ka 1.9
  create-custom-acid vol-acid                 ;; adds parent acid molecules
    [ set color yellow ]
  ask acid
    [ if (random 100.0 < Ka)                  ;; creates initial dissociated acid
        [ hatch 1
            [ set breed hydronium             ;; child turtle turns into a hydronium
              set color green
              fd 3 ]
         set breed conj-base                  ;; parent turtle turns into a conj-base
         set color orange ] ]
  create-custom-water (100 - count hydronium)
    [ set color blue ]
  ask turtles                   ;; randomize position and heading of turtles
    [ setxy (random screen-size-x) (random screen-size-y)
      rt random 360 ]
  set base-added 0
  setup-plot
  calculate-pH
  plot-pH
end

to go
  ask hydroxide [ react-hydroxide-hydronium ]
  ask hydroxide [ react-hydroxide-acid ]
  ask acid [ react-acid ]
  ask hydronium [ react-hydronium ]
  ask turtles
    [ fd 1 rt (random 10 - random 10) ]    ;; moves turtles randomly around the screen
  calculate-pH
  plot-pH
end

;; adds base molcules to the solution
to add-base
  create-custom-hydroxide vol-base
    [ fd 1
      rt random 360
      set color red ]
  set base-added base-added + vol-base
end

;; hydroxide procedure
to react-hydroxide-hydronium
  locals [ partner ]
  set partner random-one-of hydronium-here     ;; tells hydroxide to recognize hydronium
  if (partner != nobody)              ;; if you are a hydroxide molecule and you encounter a hydroxide
    [ set breed-of partner water      ;; then turn yourself and the hydronium into water molecules
      set color-of partner blue
      set breed water
      set color blue ]
end

;; hydroxide procedure
to react-hydroxide-acid
  locals [ partner ]
  if (random 100.0 < Ka)                  ;; react with acid molecules according to the acid strength
    [ set partner random-one-of acid-here
      if (partner != nobody)              ;; if you are a hydroxide molecule and you encounter an acid molecule
        [ set breed-of partner conj-base  ;; then turn the hydroxide into a conjugate base molecule
          set color-of partner orange
          set breed water                 ;; and turn yourself into a water molecule
          set color blue ] ]
end

;; acid procedure
to react-acid
  locals [ partner ]
  if (random 100.0 < Ka)                  ;; acid molecules may dissociate to hydronium depending on their Ka
    [ set partner random-one-of water-here
      if (partner != nobody)              ;; if you are an acid molecule and you encounter a water molecule
        [ set breed-of partner hydronium  ;; then turn the water molecule into a hydronium molecule
          set color-of partner green
          set breed conj-base             ;; and turn yourself into a conjugate base molecule
          set color orange ] ]
end

;; hydronium procedure
to react-hydronium
  locals [ partner ]
  if (random 100.0 < Ka)                  ;; hydronium molecules may recombine with conjugate base to form acid
    [ set partner random-one-of conj-base-here
      if (partner != nobody)              ;; if you are a hydronium molecule and you encounter a conjugate base molecule
        [ set breed-of partner acid       ;; then turn the conjugate base molecule into an acid molecule
          set color-of partner yellow
          set breed water                 ;; and turn yourself into a water molecule
          set color blue ] ]
end

;; calculates the pH from the amount of the various ions in solution;
;; note that for simplicity the calculations don't take the true molar
;; concentration of water into account, but instead use an arbitrarily
;; chosen factor of 1000 to produce numbers lying in a reasonable range
to calculate-pH
  locals [ volume concH concOH pOH ]
  set volume count turtles 
  set concH (count hydronium / volume)
  set concOH (count hydroxide / volume)
  ifelse (concH = concOH)
    [ set pH 7 ]
    [ ifelse (concH > concOH)
      [ set pH (0 - log (concH / 1000) 10) ]
      [ set pOH (0 - log (concOH / 1000) 10)
        set pH 14 - pOH ] ]
end

;; plotting procedures

to setup-plot
  set-current-plot "Titration Curve"
  set-plot-x-range 0 100
  set-plot-y-range 0 14
  auto-plot-on
  set-plot-pen-color blue

  set-current-plot "pH Curve"
  set-plot-x-range 0 100
  set-plot-y-range 0 14
  auto-plot-on
  set-plot-pen-color red
end

to plot-pH
  set-current-plot "pH Curve"
  plot pH
end

to record-pH
  if base-added = 0 [ stop ]        ;; can't plot if there's no new data
  set-current-plot "Titration Curve"
  set-plot-pen-interval base-added  ;; before next plotting, move along x-axis
                                    ;; by magnitude of amount added since last point
  plot pH
  set base-added 0
end


; *** NetLogo Model Copyright Notice ***
;
; This model was created as part of the project:
; PARTICIPATORY SIMULATIONS: NETWORK-BASED DESIGN FOR SYSTEMS LEARNING IN
; CLASSROOMS.  The project gratefully acknowledges the support of the
; National Science Foundation (REPP program) -- grant number REC #9814682.
;
; Copyright 2001 by Uri Wilensky.  Updated 2002.  All rights reserved.
;
; Permission to use, modify or redistribute this model is hereby granted,
; provided that both of the following requirements are followed:
; a) this copyright notice is included.
; b) this model will not be redistributed for profit without permission
;    from Uri Wilensky.
; Contact Uri Wilensky for appropriate licenses for redistribution for
; profit.
;
; To refer to this model in academic publications, please use:
; Wilensky, U. (2001).  NetLogo Weak Acid model.
; http://ccl.northwestern.edu/netlogo/models/WeakAcid.
; Center for Connected Learning and Computer-Based Modeling,
; Northwestern University, Evanston, IL.
;
; *** End of NetLogo Model Copyright Notice ***
@#$#@#$#@
GRAPHICS-WINDOW
335
10
695
391
12
12
14.0
1
10
0
0

CC-WINDOW
258
396
686
526
Command Center

MONITOR
265
217
324
266
pH
pH
2
1

SLIDER
6
84
187
117
vol-acid
vol-acid
0
100
100
1
1
molecules

SLIDER
6
118
186
151
vol-base
vol-base
1
100
100
1
1
molecules

BUTTON
9
41
70
74
setup
setup
NIL
1
T
OBSERVER

BUTTON
76
41
137
74
go
go
T
1
T
OBSERVER

BUTTON
217
99
293
132
add-base
add-base
NIL
1
T
OBSERVER

BUTTON
257
358
333
391
record pH
record-pH
NIL
1
T
OBSERVER

PLOT
11
350
254
526
Titration Curve
Volume base
pH
0.0
100.0
0.0
14.0
true
false

PLOT
11
165
254
348
pH Curve
Time
pH
0.0
502.0
0.0
14.0
true
false

@#$#@#$#@
WHAT IS IT?
-----------
This model demonstrates the differences in the calculation of pH when evaluating a weak acid in solution. It is best viewed as the second model in the ACID-BASE package. Unlike a strong acid, a weak acid has a very low Ka (or acid dissociation constant). Consequently, very little of the acid is dissociated into hydronium ions and conjugate base as seen in the following reaction.

|                        1%        +    -
|        H-A  + H O  <========>  H O  + A
|                2                3

Because so little hydronium ion is present, the pH of the solution cannot be calculated directly from the initial concentration of acid. Though the equation for calculating the pH is identical to that for a strong base,

|                    +
|            pH = - log [H O]
|                         3

we must first calculate the amount of hydronium ion present in the solution. This amount is dependent on the Ka of the acid. Each acid has a unique Ka, which indicates the probability that an acid molecule will react with a water molecule to form a hydronium ion and an anion. The anion in such a reaction is known as the conjugate base of the original acid. Though the term conjugate base may seem strange, it makes sense if you look at the chemical equation above. There A- is the conjugate base of H-A because it can take a proton from the hydronium ion to generate the original acid.

This model models the composition of a weakly acidic solution and allows the user to observe how altering the species in solution affects the pH. In the model, the dissociation constant Ka, is much higher than the real Ka for an acid. In fact, the model uses the following formula to convert he real-world Ka into a simulated Ka for the model:

|    Ka for MODEL = 11 - pKa (pKa = - log (real-world Ka)


HOW TO USE IT
--------------
Decide how much acid should be present at the start of the simulation with the VOL-ACID slider and press SETUP. Turtles will distribute randomly across the screen. BLUE turtles represent water molecules, GREEN turtles represent hydronium ions, YELLOW turtles are acid molecules, and finally ORANGE turtles are conjugate base molecules. A set amount of water molecules is added each time to the solution. In this model we are using the Ka of acetic, which means that approximately 1% of the original acid molecules are dissociated into 1 conjugate base molecule and 1 hydronium molecule.

Press GO. The turtles will move randomly across the screen and the pH of the solution will by plotted over time on the pH Curve and displayed in the pH monitor.

Observe the effect of adding RED base molecules to the solution by setting the volume of base with the VOL-BASE (mL) slider and pressing ADD-BASE.

At any time while go is depressed, RECORD-PH can be pressed to plot the pH versus the amount of base added on the Titration Curve.


THINGS TO NOTICE
----------------
Observe how the pH curve changes over time with the addition of base. How is this curve different from that seen in the strong acid model? Plot a titration curve and compare it with a strong acid.

Does the value of VOL-BASE affect the titration curve in any way? Is this different from the relationship between strong acids and strong bases?

Why are the base molecules not reacting with the water molecules? Does it matter?


THINGS TO TRY
-------------
Notice that the pH of the solution seems to be an average rather than a constant. Can you explain this?

Start the model with various amounts of acid. How does this affect the titration curve? Is there any difference in the endpoint of the reaction?

Keep adding base until the pH rises to about 10. Notice the breeds of turtles on the screen. How does the pH depend on the molecules present?

Notice that in our models acid molecules react with base molecules based on the value of Ka. Make a slider so that you can alter this value. Observe how the system changes with regard to this variable. Is your pH between 0-14?

WARNING: We have established a constant for Ka in the procedures window. You must remove that constant when you replace it with a slider of the same name.


EXTENDING THE MODEL
------------------
Notice that the code requires hydroxide molecules to first react with hydronium molecules on a patch before they react with acid molecules. This is because hydroxide and hydronium react much more rapidly than hydroxide does with a weak acid. Reverse the code and observe the effect on the system.

Alter the code so that base turtles only react with hydronium molecules. What effect is observed? What additional changes do you need to make so that the pH continues to rise with the addition of base?

Increase the dissociation percentage so that more hydronium ions are generated at setup. What does this do to the pH? Can you predict what the Ka of a strong acid might be?

Try using the various pKa values listed below to determine the endpoint of each weak acid.

|    weak acid   Ka              pKa  Ka for model
|    ---------------------------------------------
|    HCN         1.26 x 10^-9    9.1      1.9
|    HOAc        1.8 x 10^-5     4.8      6.2
|    H2CO3       3.16 x 10^-7    6.5      4.5
|    HCO2H       2.0 x 10^-4     3.7      7.3


NETLOGO FEATURES
------------------
Notice the large number of breeds used in this model. Because of the complex interactions between molecules in a weakly acidic solution, it is necessary to separate turtles according to their identity. This allows each breed of turtle to follow unique instructions, which allows the model to simulate the complexity of molecular interactions.


CREDITS AND REFERENCES
----------------------
Thanks to Mike Stieff for his work on this model.

To refer to this model in academic publications, please use: Wilensky, U. (2001).  NetLogo Weak Acid model. http://ccl.northwestern.edu/netlogo/models/WeakAcid. Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.
@#$#@#$#@
default
true
0
Polygon -7566196 true true 150 5 40 250 150 205 260 250

molecule1
true
0
Circle -7566196 true true 80 80 142
Circle -1 true false 52 195 61

molecule2
true
0
Circle -7566196 true true 78 79 146
Circle -1 true false 40 41 69
Circle -1 true false 194 42 71

molecule3
true
0
Circle -7566196 true true 92 92 118
Circle -1 true false 120 32 60
Circle -1 true false 58 183 60
Circle -1 true false 185 183 60

@#$#@#$#@
NetLogo 1.3beta1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
